@@ -5,7 +5,7 @@
 .. module:: Plugin
    :platform: Unix
    :synopsis: Wraps Nagios plugins in a candy coating.
-.. moduleauthor:: Shaun Thomas <shaun@bonesmoses.org>
+.. moduleauthor:: Steven Schlegel <steven@schlegel.tech>
 
 The Plugin module provides all the parts necessary to create a simple Nagios
 report for a service or host check by removing all that pesky inside
@@ -15,6 +15,10 @@ creation to a few lines of python unless the plugin is especially complex.
 All specifications for this module are obtained from the `Nagios developer
 documentation <http://nagiosplug.sourceforge.net/developer-guidelines.html>`_.
 
+Author (Original): Shaun Thomas
+Vendor (Original): Leapfrog Online
+Source (Original): https://github.com/bonesmoses/NagAconda
+
 Usage
 -----
 
@@ -46,7 +50,7 @@ API Specification
 
 """
 
-__version__ = '0.2.1'
+__version__ = '0.3.5'
 __all__ = ['Plugin']
 
 # We need the option parser primarily to provide an instruction harness to the
@@ -141,7 +145,7 @@ class Plugin:
         # Before we really do anything, make sure a warning or critical 
         # threshold were even set.
 
-        print 'range was ' + range_type
+        self.__verbose_print('range was ' + range_type)
 
         range_list = self.__warning
         if range_type == 'critical':
@@ -160,22 +164,23 @@ class Plugin:
         if len(range_list) < threshold:
             if range_type not in self.__req_option:
                 return
-            raise UserWarning, (
-                "Please set part %s of the %s threshold!" % (
-                threshold, range_type))
+            raise UserWarning ("Please set part %s of the %s threshold!" % (threshold, range_type))
 
         # The option parser should have already split these into proper
         # bottom, top, and match inversion, so long as the array element
         # is defined Perform our range test and set the exit status.
-        print range_list[threshold-1]
-        (bottom, top, invert) = range_list[threshold-1]
+
+        self.__verbose_print(range_list[threshold-1])
+        (bottom, top, invert, raw) = range_list[threshold-1]
+
+        self.__perf[name]["raw_%s" % range_type] = raw
 
         if ((not invert and (val < bottom or val > top)) or
            (invert and val >= bottom and val <= top)):
             self.__exit_status = range_type
             self.__perf[name]['state'] = range_type
 
-        print "%s:%s:%s =  %s" % (val, bottom, top, ((val < bottom) or (val > top)))
+        self.__verbose_print("%s:%s:%s =  %s" % (val, bottom, top, ((val < bottom) or (val > top))))
 
     def add_option(self, flag, name, helptext, **kwargs):
         """
@@ -200,7 +205,7 @@ class Plugin:
 
         opt_usage = "-%s %s" % (flag, name.upper())
 
-        if kwargs.has_key('required') and kwargs['required'] is True:
+        if 'required' in kwargs and kwargs['required'] is True:
             self.__req_option.append(name)
         else:
             opt_usage = "[%s]" % opt_usage
@@ -270,10 +275,13 @@ class Plugin:
             self.unknown_error("Start method must be called first!")
 
         exit_value = 0
-        if self.__exit_status == 'warning':
-            exit_value = 1
-        if self.__exit_status == 'critical':
-            exit_value = 2
+        for perf_dict in self.__perf.values():
+            if perf_dict['state'] == 'warning' and exit_value < 1:
+                exit_value = 1
+                self.__exit_status = 'warning'
+            elif perf_dict['state'] == 'critical' and exit_value < 2:
+                exit_value = 2
+                self.__exit_status = 'critical'
 
         # Nagios performance output is values delimited by a space. semicolons
         # separate to val;warn;crit;min;max with the scale included in all
@@ -285,9 +293,10 @@ class Plugin:
 
             perfs.append('%s=%s%s;%s;%s;%s;%s' % (
                 perf_name, perf_dict['val'], perf_dict['scale'] or '',
-                self.options.ensure_value('raw_warning', ''),
-                self.options.ensure_value('raw_critical', ''),
-                perf_dict['min'] or '', perf_dict['max'] or '')
+                perf_dict.get('raw_warning', ''),
+                perf_dict.get('raw_critical', ''),
+                '' if perf_dict['min'] is None else perf_dict['min'],
+                '' if perf_dict['max'] is None else perf_dict['max'])
             )
 
         perf_string = ''
@@ -298,7 +307,7 @@ class Plugin:
         if self.__exit_message is not None:
             exit_status += ', %s' % self.__exit_message
 
-        print 'Status ' + exit_status + perf_string
+        print('Status ' + exit_status + perf_string)
         sys.exit(exit_value)
 
     def set_range(self, range_type, range_end, range_start=0,
@@ -415,20 +424,20 @@ class Plugin:
         val_dict = {'val': val, 'min': None, 'max': None, 'scale': None,
             'threshold': 1, 'state': 'ok'}
 
-        if kwargs.has_key('lowest'):
+        if 'lowest' in kwargs:
             val_dict['min'] = float(kwargs.get('lowest'))
 
-        if kwargs.has_key('highest'):
+        if 'highest' in kwargs:
             val_dict['max'] = float(kwargs.get('highest'))
 
-        if kwargs.has_key('threshold'):
+        if 'threshold' in kwargs:
             val_dict['threshold'] = kwargs['threshold']
 
         # Nagios actually understands most byte and time oriented scales.
         # The developer docs also list a counter scale, but we're not certain
         # if any plugin has ever used that. Only accept known scales.
 
-        if kwargs.has_key('scale'):
+        if 'scale' in kwargs:
             scale = kwargs.get('scale')
 
             if scale.upper() in ('B', 'KB', 'MB', 'GB', 'TB'):
@@ -445,11 +454,11 @@ class Plugin:
         # variable is set so we don't have to loop through all of them later.
 
         if len(self.__warning) > 0:
-            print "checking warning"
+            self.__verbose_print("checking warning")
             self.__check_range('warning', name)
 
         if len(self.__critical) > 0:
-            print "checking critical"
+            self.__verbose_print("checking critical")
             self.__check_range('critical', name)
 
         return self.__perf[name]['state']
@@ -544,9 +553,15 @@ class Plugin:
         :type message: string
 
         """
-        print 'Status Unknown: ' + message
+        print('Status Unknown: ' + message)
         sys.exit(3)
 
+    def __verbose_print(self, *args):
+        if self.options.verbose is not None:
+            for arg in args:
+                print(arg),
+            print
+
 def convert_range(option, opt_str, value, parser):
     """
     Convert a warning/critical range into separate testable variables.
@@ -594,6 +609,8 @@ def get_range(value):
         max boundaries for the range, and whether or not to invert the match.
     """
 
+    raw = value
+
     # If we find a '@' at the beginning of the range, we should invert
     # the match.
 
@@ -626,7 +643,7 @@ def get_range(value):
     else:
         top = float(value)
 
-    return (bottom, top, invert)
+    return (bottom, top, invert, raw)
 
 if __name__ == "__main__":
     PLUGTEST = Plugin()
